<?php

/**
 * @file
 * Contains administrative forms and their handlers.
 */

/**
 * Get star sign based on DOB form.
 */
function _get_birth_sign_form() {
  $form['dob'] = array(
    '#type' => 'date',
    '#title' => t('Select Date of Birth'),
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Find'),
  );
  return $form;
}

/**
 * Get star sign based on DOB form_submit.
 */
function _get_birth_sign_form_submit($form_id, $form_values) {
  $day = $form_values['values']['dob']['day'];
  $month = $form_values['values']['dob']['month'];
  $query = db_select('astrology_signs', 'h')
    ->fields('h', array('id', 'name', 'date_from_range', 'date_to_range'))
    ->execute();
  while ($row = $query->fetchObject()) {
    $fdate = explode('/', $row->date_from_range);
    $tdate = explode('/', $row->date_to_range);
    if ($month == $fdate[0] && $day >= $fdate[1] || $month == $tdate[0] && $day <= $tdate[1]) {
      drupal_goto('astrology/' . drupal_strtolower($row->name) . '/sunsign');
      break;
    }
  }
}

/**
 * Astrology edit form.
 */
function astrology_edit_form($form_state, $form_id, $arg) {
  $astrology = _get_astrology_array($arg);
  $form['id'] = array(
    '#type' => 'hidden',
    '#default_value' => $astrology['id'],
  );
  $form['name'] = array(
    '#type' => 'textfield',
    '#default_value' => $astrology['name'],
    '#title' => t('Name'),
    '#required' => TRUE,
  );
  $form['enabled'] = array(
    '#type' => 'checkbox',
    '#default_value' => $astrology['enabled'],
    '#title' => t('Enabled'),
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );
  return $form;
}

/**
 * Astrology edit form_validate.
 */
function astrology_edit_form_validate(&$form_id, &$form_values) {

  // Check if astrology name exists.
  $result = db_query("SELECT name FROM {astrology} WHERE name = :name AND id <> :id ", array(':name' => $form_values['values']['name'], ':id' => $form_values['values']['id']));

  if ($result->rowCount() > 0) {
    form_set_error('name', 'Astrology name ' . $form_values['values']['name'] . ' already taken');
    $form_values['rebuild'] = TRUE;
  }
}

/**
 * Astrology edit form_submit.
 */
function astrology_edit_form_submit($form_id, $form_values) {

  $exists = db_query("SELECT *  FROM {astrology} WHERE id = :id", array(':id' => $form_values['values']['id']));
  if ($exists->fetchAssoc()) {
    db_update('astrology')
      ->fields(array(
        'name' => $form_values['values']['name'],
        'enabled' => $form_values['values']['enabled'],
      ))
      ->condition('id', $form_values['values']['id'], '=')
      ->execute();
    check_default_astrology($form_values['values']['id'], $form_values['values']['enabled']);
    drupal_set_message(t('Updated astrology %name', array('%name' => $form_values['values']['name'])));
  }
}

/**
 * Astrology add form.
 */
function astrology_add_form() {

  $form['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name'),
    '#required' => TRUE,
  );
  $form['enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enabled'),
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );
  return $form;
}

/**
 * Astrology add form_validate.
 */
function astrology_add_form_validate(&$form_id, &$form_values) {

  // Check if astrology name exists.
  $result = db_query("SELECT name FROM {astrology} WHERE name = :name ", array(':name' => $form_values['values']['name']));
  if ($result->rowCount() > 0) {
    form_set_error('name', 'Astrology name ' . $form_values['values']['name'] . ' is already taken');
    $form_values['rebuild'] = TRUE;
  }
}

/**
 * Astrology add form_submit.
 */
function astrology_add_form_submit($form_id, $form_values) {

  // Insert astrology to DB.
  $astrology_id = db_insert('astrology')
    ->fields(array(
      'name' => $form_values['values']['name'],
      'enabled' => $form_values['values']['enabled'],
    ))->execute();
  check_default_astrology($astrology_id, $form_values['values']['enabled'], TRUE);
  drupal_set_message(t('Astrology %name created', array('%name' => $form_values['values']['name'])));
}

/**
 * Delete astrology sign form.
 */
function astrology_delete_sign_form($form_state, $form_id, $arg3) {

  $astrology_sign = _astrology_sign_array($arg3);
  $destination = drupal_get_destination();

  if ($astrology_sign['astrology_id'] == 1) {
    drupal_set_message(t("You can\'t delete this sing"), 'error');
  }

  $form['id'] = array(
    '#type' => 'hidden',
    '#default_value' => $astrology_sign['id'],
  );
  $form['name'] = array(
    '#type' => 'hidden',
    '#default_value' => $astrology_sign['name'],
  );
  $form['astrology_id'] = array(
    '#type' => 'hidden',
    '#default_value' => $astrology_sign['astrology_id'],
  );
  return confirm_form(
   $form,
   t('Are you sure you want to delete this !name?', array('!name' => $astrology_sign['name'])),
   $destination,
   t('This action cannot be undone.'),
   t('Delete'),
   t('Cancel')
   );
}

/**
 * Delete astrology sign form_submit.
 */
function astrology_delete_sign_form_submit($form_id, $form_values) {

  $astrology_id = $form_values['values']['astrology_id'];
  $sign_id = $form_values['values']['id'];

  // Delete all text for particular sign id, before deleting sign.
  db_delete('astrology_text')
    ->condition('astrology_sign_id', $sign_id, '=')
    ->execute();

  // Finally deleting sign.
  db_delete('astrology_signs')
    ->condition('id', $sign_id, '=')
    ->condition('astrology_id', $astrology_id, '=')
    ->execute();
  drupal_set_message(t("Sing %name deleted.", array('%name' => $form_values['values']['name'])));
}

/**
 * Edit astrology sign form.
 */
function astrology_edit_sign_form($form_state, $form_id, $arg3) {
  $astrology_sign = _astrology_sign_array($arg3);
  if ($astrology_sign['astrology_id'] == 1) {
    $bool = TRUE;
  }
  else {
    $bool = FALSE;
  }
  $form['id'] = array(
    '#type' => 'hidden',
    '#default_value' => $astrology_sign['id'],
  );
  $form['astrology_id'] = array(
    '#type' => 'hidden',
    '#default_value' => $astrology_sign['astrology_id'],
  );
  $form['name'] = array(
    '#type' => 'textfield',
    '#default_value' => $astrology_sign['name'],
    '#title' => t('Name'),
    '#required' => TRUE,
    '#disabled' => $bool,
  );
  $form['icon'] = array(
    '#type' => 'file',
    '#default_value' => $astrology_sign['icon'],
    '#title' => t('icon'),
  );
  $form['from_date'] = array(
    '#type' => 'textfield',
    '#title' => t('From date (MM/DD)'),
    '#default_value' => $astrology_sign['date_from_range'],
    '#required' => TRUE,
    '#disabled' => $bool,
  );
  $form['to_date'] = array(
    '#type' => 'textfield',
    '#title' => t('To date (MM/DD)'),
    '#default_value' => $astrology_sign['date_to_range'],
    '#required' => TRUE,
    '#disabled' => $bool,
  );
  $form['about'] = array(
    '#type' => 'textarea',
    '#title' => t('Text about this sign'),
    '#default_value' => $astrology_sign['about_sign'],
    '#required' => TRUE,
    '#disabled' => $bool,
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Update'),
  );
  return $form;
}

/**
 * Edit astrology sign form_validate.
 */
function astrology_edit_sign_form_validate(&$form_id, &$form_values) {
  $from_date = explode('/', $form_values['values']['from_date']);
  $to_date = explode('/', $form_values['values']['to_date']);
  if (($from_date[0] <= 0 || $from_date[0] > 12) || ($from_date[1] <= 0 || $from_date[1] > 31)) {
    form_set_error('from_date', 'Invalid date.');
    $form_values['rebuild'] = TRUE;
  }
  if (($to_date[0] <= 0 || $to_date[0] > 12) || ($to_date[1] <= 0 || $to_date[1] > 31)) {
    form_set_error('to_date', 'Invalid date.');
    $form_values['rebuild'] = TRUE;
  }
}

/**
 * Edit astrology sign form_submit.
 */
function astrology_edit_sign_form_submit($form_id, $form_values) {
  $file_path = 'public://astrology/image';
  file_prepare_directory($file_path, FILE_CREATE_DIRECTORY);
  $validators = array();
  if ($file = file_save_upload('icon', $validators, $file_path, FILE_EXISTS_REPLACE)) {
    $file->status = FILE_STATUS_PERMANENT;
    db_update('astrology_signs')
      ->fields(array(
        'name' => $form_values['values']['name'],
        'icon' => $file->uri,
        'date_from_range' => $form_values['values']['from_date'],
        'date_to_range' => $form_values['values']['to_date'],
        'about_sign' => $form_values['values']['about'],
      ))
      ->condition('id', $form_values['values']['id'], '=')
      ->condition('astrology_id', $form_values['values']['astrology_id'], '=')
      ->execute();
    file_save($file);
    drupal_set_message(t('Updated %name', array('%name' => $form_values['values']['name'])));
  }
  else {
    db_update('astrology_signs')
      ->fields(array(
        'name' => $form_values['values']['name'],
        'date_from_range' => $form_values['values']['from_date'],
        'date_to_range' => $form_values['values']['to_date'],
        'about_sign' => $form_values['values']['about'],
      ))
      ->condition('id', $form_values['values']['id'], '=')
      ->condition('astrology_id', $form_values['values']['astrology_id'], '=')
      ->execute();
    drupal_set_message(t('Updated %name', array('%name' => $form_values['values']['name'])));
  }
}

/**
 * Add astrology sign form.
 */
function astrology_add_sign_form($form_state, $form_id, $arg) {

  $destination = drupal_get_destination();
  if ($arg == 1) {
    drupal_set_message(t('No more sign can be added'), 'error');
    drupal_goto($destination);
  }
  $module_path = drupal_get_path('module', 'astrology');
  $form['astrology_id'] = array(
    '#type' => 'hidden',
    '#default_value' => $arg,
  );
  $form['name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name'),
    '#required' => TRUE,
  );
  $form['icon'] = array(
    '#type' => 'file',
    '#title' => t('icon'),
  );
  $form['from_date'] = array(
    '#type' => 'textfield',
    '#title' => t('From date (MM/DD)'),
    '#required' => TRUE,
  );
  $form['to_date'] = array(
    '#type' => 'textfield',
    '#title' => t('To date (MM/DD)'),
    '#required' => TRUE,
  );
  $form['about'] = array(
    '#type' => 'textarea',
    '#title' => t('Note: text must be 500 character long.'),
    '#required' => TRUE,
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );
  return $form;
}

/**
 * Add astrology sign form_validate.
 */
function astrology_add_sign_form_validate(&$form_id, &$form_values) {
  $fv = $form_values['values']['from_date'];
  $tv = $form_values['values']['to_date'];
  if (preg_match("/^[0-9]{1,2}\/[0-9]{1,2}$/", $fv) && preg_match("/^[0-9]{1,2}\/[0-9]{1,2}$/", $tv)) {
    $from_date = explode('/', $fv);
    $to_date = explode('/', $tv);
    if (($from_date[0] <= 0 || $from_date[0] > 12) || ($from_date[1] <= 0 || $from_date[1] > 31)) {
      form_set_error('from_date', 'Invalid date.');
      $form_values['rebuild'] = TRUE;
    }
    if (($to_date[0] <= 0 || $to_date[0] > 12) || ($to_date[1] <= 0 || $to_date[1] > 31)) {
      form_set_error('to_date', 'Invalid date.');
      $form_values['rebuild'] = TRUE;
    }
  }
  else {
    form_set_error('to_date', 'Invalid date format should be (MM/DD).');
    form_set_error('from_date', 'Invalid date format should be (MM/DD)');
  }
  if (strlen($form_values['values']['about']) < 250) {
    form_set_error('about', 'Text must be 250 character long and terminate with (.)');
    $form_values['rebuild'] = TRUE;
  }
}

/**
 * Add astrology sign form_submit.
 */
function astrology_add_sign_form_submit($form_id, $form_values) {
  $file_path = 'public://astrology/image';
  $validators = array();
  $exists = db_query("SELECT name  FROM {astrology_signs} WHERE name = :name", array(':name' => $form_values['values']['name']));
  if ($exists->rowCount() > 0) {
    drupal_set_message(t('Oops! sign already exists.'), 'error');
  }
  else {
    file_prepare_directory($file_path, FILE_CREATE_DIRECTORY);
    if ($file = file_save_upload('icon', $validators, $file_path, FILE_EXISTS_REPLACE)) {
      $file->status = FILE_STATUS_PERMANENT;
      db_insert('astrology_signs')
        ->fields(array(
          'astrology_id' => $form_values['values']['astrology_id'],
          'name' => $form_values['values']['name'],
          'icon' => $file->uri,
          'date_from_range' => $form_values['values']['from_date'],
          'date_to_range' => $form_values['values']['to_date'],
          'about_sign' => $form_values['values']['about'],
        ))
        ->execute();
      file_save($file);
      drupal_set_message(t('Inserted %name:', array('%name' => $form_values['values']['name'])));
    }
    else {
      db_insert('astrology_signs')
        ->fields(array(
          'astrology_id' => $form_values['values']['astrology_id'],
          'name' => $form_values['values']['name'],
          'date_from_range' => $form_values['values']['from_date'],
          'date_to_range' => $form_values['values']['to_date'],
          'about_sign' => $form_values['values']['about'],
        ))
        ->execute();
      drupal_set_message(t('Inserted %name:', array('%name' => $form_values['values']['name'])));
    }
  }
}

/**
 * Astrology delete form.
 */
function astrology_delete_form($form_state, $form_id, $arg) {

  $destination = drupal_get_destination();

  if ($arg == 1) {
    drupal_set_message(t("You can\'t delete this astrology"), 'error');
    drupal_goto($destination);
  }
  if (variable_get('astrology_default') == $arg) {
    drupal_set_message(t("You can\'t delete this astrology, as its enabled, please disable to delete."), 'error');
    drupal_goto($destination);
  }

  $form['id'] = array(
    '#type' => 'hidden',
    '#default_value' => $arg,
  );
  return confirm_form(
   $form,
   t('Are you sure you want to delete this item?'),
   $destination,
   t('This action cannot be undone.'),
   t('Delete'),
   t('Cancel')
   );
}

/**
 * Astrology delete form_submit.
 */
function astrology_delete_form_submit($form_id, $form_values) {

  $astrology_id = $form_values['values']['id'];
  $result = db_query("SELECT enabled,name FROM {astrology} WHERE id = :id ",
  array(':id' => $astrology_id));
  $row = $result->fetchObject();

  // Get all sign ids.
  $sign_ids = db_query("SELECT id FROM {astrology_signs} WHERE astrology_id = :id ",
  array(':id' => $astrology_id));

  // Delete all text for particular sign id.
  while ($ids = $sign_ids->fetchObject()) {
    db_query("DELETE FROM {astrology_text} WHERE astrology_sign_id = :id",
    array(':id' => $ids->id));
  }

  // Now deleted all sign ids.
  db_query("DELETE FROM {astrology_signs} WHERE astrology_id = :id",
  array(':id' => $astrology_id));

  // Finally delete astrology.
  $result = db_query("DELETE FROM {astrology} WHERE id = :id",
  array(':id' => $astrology_id));

  if ($result->rowCount()) {
    drupal_set_message(t("Astrology %name deleted.", array('%name' => $row->name)));
  }
}

/**
 * Astrology add sign text form.
 */
function astrology_add_text_form($form_id, $form_values, $arg1, $arg2) {
  /*Only day and week format uses datepicker*/
  /*Jquery UI Theme not included by default*/
  drupal_add_library('system', 'ui.datepicker');
  drupal_add_js(drupal_get_path('module', 'astrology') . '/js/add_text.js');
  switch (variable_get('astrology_format', 'day')) {
    default:
    case 'day':
      $format = 'z';
      $value  = array(
        '#type' => 'textfield',
        '#title' => t('Select Day'),
        '#required' => TRUE,
      );
      break;
    case 'week':
      $format = 'W';
      $value  = array(
        '#type' => 'textfield',
        '#title' => t('Select Week'),
        '#required' => TRUE,
      );
      break;

    case 'month':
      $format = 'n';
      $value  = array(
        '#type' => 'select',
        '#title' => t('Select Month'),
        '#options' => months_array(),
      );
      break;

    case 'year':
      $format = 'o';
      $value  = array(
        '#type' => 'select',
        '#title' => t('Select Year'),
        '#options' => years_array(),
      );
      break;
  }
  $options = _astrology_sign_array($arg2);
  $form['label'] = array(
    '#markup' => t('!name', array('!name' => $options['name'])),
  );
  $form['astrology_sign_id'] = array(
    '#type' => 'hidden',
    '#default_value' => $arg2,
  );
  $form['format_character'] = array(
    '#type' => 'hidden',
    '#default_value' => $format,
  );
  $form['value'] = $value;
  $form['text'] = array(
    '#type' => 'textarea',
    '#title' => t('Enter Text'),
    '#required' => TRUE,
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );
  return $form;
}

/**
 * Astrology add sign text form_submit.
 */
function astrology_add_text_form_submit($form_id, $form_values) {
  $values = $form_values['values'];
  switch ($values['format_character']) {
    case 'z':
      // Get day and month: mm-dd.
      $date = explode('/', $values['value']);
      $post_date = mktime(0, 0, 0, $date[0], $date[1], $date[2]);
      $month = $date[0];
      $day = $date[1];
      // Get day number of the year.
      $date = date('z', mktime(0, 0, 0, $month, $day));
      $date_message = dayofyear2date($date + 1, 'l j F');
      break;

    case 'W':
      // Get day and month: mm-dd.
      $date = explode('/', $values['value']);
      $post_date = mktime(0, 0, 0, $date[0], $date[1], $date[2]);
      $month = $date[0];
      $day = $date[1];
      // Get week number of the year.
      $date = date('W', mktime(0, 0, 0, $month, $day));
      $date_message = 'week ' . date('j, M', mktime(0, 0, 0, date("n", $post_date), date("j", $post_date) - date("N", $post_date))) . ' to ';
      $date_message .= date('j, M', mktime(0, 0, 0, date("n", $post_date), date("j", $post_date) - date("N", $post_date) + 6));
      break;

    case 'n':
      // Get day and month: mm-dd.
      $date = $values['value'];
      $post_date = mktime(0, 0, 0, $date);
      $date = $values['value'];
      $date_message = 'month ' . date('n', mktime(0, 0, 0, $values['value']));
      break;

    case 'o':
      // Get day and month: mm-dd.
      $date = $values['value'];
      $post_date = mktime(0, 0, 0, 1, 1, $date);
      $date = $values['value'];
      $date_message = 'year ' . $values['value'];
      break;
  }
  // Check if data for sign already exists for this format.
  $result = db_select('astrology_text', 'at')
    ->fields('at', array('id', 'astrology_sign_id'))
    ->condition('astrology_sign_id', $values['astrology_sign_id'], '=')
    ->condition('format_character', $values['format_character'], '=')
    ->condition('value', $date, '=')
    ->execute();

  if ($result->rowCount()) {
    $row = $result->fetchObject();
    variable_set('text', $values['text']);
    drupal_goto('admin/config/astrology/list/' . $row->astrology_sign_id . '/signs/' . $row->id . '/replace_text');
  }
  else {
    db_insert('astrology_text')
      ->fields(array(
        'astrology_sign_id' => $values['astrology_sign_id'],
        'format_character' => $values['format_character'],
        'value' => $date,
        'text' => $values['text'],
        'post_date' => $post_date,
      ))
      ->execute();
    drupal_set_message(t('Text added for %date', array('%date' => $date_message)));
  }
}

/**
 * Astrology sign replace text for existing date and format form.
 */
function astrology_sign_replace_text_form($form_state, $form_id, $astrology_id, $sign_id) {

  $destination = 'admin/config/astrology/list/' . $astrology_id . '/signs/' . $sign_id . '/add_text';

  $form['astrology_id'] = array(
    '#type' => 'hidden',
    '#default_value' => $astrology_id,
  );
  $form['sign_id'] = array(
    '#type' => 'hidden',
    '#default_value' => $sign_id,
  );
  return confirm_form(
   $form,
   t('It seems there is already data for this, would you like to update?'),
   $destination,
   t('This action cannot be undone.'),
   t('Update'),
   t('Cancel')
   );
}

/**
 * Astrology sign replace text for existing date and format form.
 */
function astrology_sign_replace_text_form_submit($form_id, $form_values) {

  $astrology_id = $form_values['values']['astrology_id'];
  $sign_id = $form_values['values']['sign_id'];
  $text = variable_get('text', NULL);
  db_update('astrology_text')
    ->fields(array(
      'text' => $text,
    ))
    ->condition('id', $sign_id, '=')
    ->execute();
  drupal_set_message(t("Data updated !"));
  drupal_goto('admin/config/astrology/list/' . $astrology_id . '/signs/' . $sign_id . '/add_text');
}

/**
 * Astrology search text form.
 */
function astrology_search_text_form($form_id, $form_value, $astrology_id) {
  drupal_add_library('system', 'ui.datepicker');
  drupal_add_js(drupal_get_path('module', 'astrology') . '/js/add_text.js');
  $format = variable_get('astrology_format', 'day');
  $options = _astrology_sign_list_array($astrology_id);
  $form['fordate'] = array(
    '#type' => 'fieldset',
    '#title' => t('Show only items where'),
  );
  switch ($format) {
    default:
    case 'day':
      $value  = array(
        '#type' => 'textfield',
        '#title' => t('Day'),
        '#required' => TRUE,
        '#default_value' => variable_get('cdate', date('m/d/Y')),
      );
      $sign_id  = array(
        '#type' => 'select',
        '#title' => t('Sign'),
        '#options' => $options,
        '#default_value' => variable_get('sign_id', 0),
      );
      break;
    case 'week':
      $format = 'W';
      $value  = array(
        '#type' => 'textfield',
        '#title' => t('Week'),
        '#required' => TRUE,
        '#default_value' => variable_get('cdate', date('m/d/Y')),
      );
      $sign_id  = array(
        '#type' => 'select',
        '#title' => t('Sign'),
        '#options' => $options,
        '#default_value' => variable_get('sign_id', 0),
      );
      break;

    case 'month':
      $value  = array(
        '#type' => 'select',
        '#title' => t('Month'),
        '#options' => months_array(),
        '#default_value' => variable_get('cdate', date('n')),
      );
      $sign_id  = array(
        '#type' => 'select',
        '#title' => t('Sign'),
        '#options' => $options,
        '#default_value' => variable_get('sign_id', 0),
      );
      break;

    case 'year':
      $value  = array(
        '#type' => 'select',
        '#title' => t('Year'),
        '#options' => years_array(),
        '#default_value' => variable_get('cdate', date('o')),
      );
      $sign_id  = array(
        '#type' => 'select',
        '#title' => t('Sign'),
        '#options' => $options,
        '#default_value' => variable_get('sign_id', 0),
      );
      break;
  }
  $form['fordate']['sign_id'] = $sign_id;
  $form['fordate']['value'] = $value;
  $form['fordate']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Find'),
  );
  $form['item'] = array(
    '#markup' => t('Search result for !format - !cdate', array(
      '!format' => variable_get('astrology_format', 'day'),
      '!cdate' => variable_get('cdate', date('m/d/Y')),
    )),
  );
  return $form;
}

/**
 * Astrology search text form_validate.
 */
function astrology_search_text_form_validate($form_id, $form_value) {
  $date = $form_value['values']['value'];
  $format = variable_get('astrology_format', 'day');
  if ($format == 'day' || $format == 'week') {
    if (preg_match("/^[0-9]{1,2}\/[0-9]{1,2}\/[0-9]{4}$/", $date)) {
      $newdate = explode('/', $form_value['values']['value']);
      if (!checkdate($newdate[0], $newdate[1], $newdate[2])) {
        form_set_error('value', 'Invalid date format should be (MM/DD/YYYY)');
      }
    }
    else {
      form_set_error('value', 'Invalid date format should be (MM/DD/YYYY)');
    }
  }
}

/**
 * Astrology search text form_submit.
 */
function astrology_search_text_form_submit($form_id, $form_value) {
  $cdate = $form_value['values']['value'];
  $sign_id = $form_value['values']['sign_id'];
  variable_set('cdate', $cdate);
  variable_set('sign_id', $sign_id);
}

/**
 * Astrology edit sign text form.
 */
function astrology_edit_text_form($form_id, $form_value, $arg) {
  $value = _get_astrology_sign_text($arg);
  $form['id'] = array(
    '#type' => 'hidden',
    '#default_value' => $arg,
  );
  $form['text'] = array(
    '#type' => 'textarea',
    '#title' => t('Enter Text'),
    '#default_value' => $value['text'],
    '#required' => TRUE,
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save'),
  );
  return $form;
}

/**
 * Astrology edit sign text form_submit.
 */
function astrology_edit_text_form_submit($form_id, $form_value) {
  db_update('astrology_text')
    ->fields(array(
      'text' => $form_value['values']['text'],
    ))
    ->condition('id', $form_value['values']['id'], '=')
    ->execute();
  drupal_set_message(t("Data updated !"));
}

/**
 * Set Default astrology.
 *
 * Set Default Format (day, week, month or year).
 *
 * Default astrology: Zodiac (id=1).
 *
 * Default format: day.
 *
 * Astrology settings form.
 */
function astrology_set_default_form() {
  $form['item'] = array(
    '#type' => 'fieldset',
    '#title' => t('Default format to display astrology'),
  );
  $formats = array(
    'day' => t('Day'),
    'week' => t('Week'),
    'month' => t('Month'),
    'year' => t('Year'),
  );
  $form['item']['format_character'] = array(
    '#type' => 'select',
    '#title' => t('Format'),
    '#options' => $formats,
    '#default_value' => variable_get('astrology_format', 'day'),
  );
  $options = _get_astrology_list_array();
  $form['item']['astrology'] = array(
    '#type' => 'select',
    '#title' => t('Astrology'),
    '#options' => $options,
    '#default_value' => variable_get('astrology_default', 1),
  );
  $form['item']['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Set'),
  );
  return $form;
}

/**
 * Astrology settings form_submit.
 */
function astrology_set_default_form_submit($form_id, $form_values) {
  switch ($form_values['values']['format_character']) {
    case 'day':
      $cdate = date('m/d/Y');
      break;

    case 'week':
      $cdate = date('m/d/Y');
      break;

    case 'month':
      $cdate = date('n', mktime(0, 0, 0, date('m'), date('d'), date('y')));
      break;

    case 'year':
      $cdate = date('o', mktime(0, 0, 0, date('m'), date('d'), date('y')));
      break;

  }
  $result = db_query("SELECT id,name FROM {astrology} WHERE id = :id ", array(':id' => $form_values['values']['astrology']));
  $row = $result->fetchObject();
  db_update('astrology')
    ->fields(array(
      'enabled' => 0,
    ))
    ->execute();
  db_update('astrology')
    ->fields(array(
      'enabled' => 1,
    ))
    ->condition('id', $row->id, '=')
    ->execute();

  variable_set('sign_id', 0);
  variable_set('cdate', $cdate);
  variable_set('astrology_default', $form_values['values']['astrology']);
  variable_set('astrology_format', $form_values['values']['format_character']);
  drupal_set_message(t('Success, Default astrology(%astrology) will be shown per %format', array('%astrology' => $row->name, '%format' => $form_values['values']['format_character'])));
}
