<?php

/**
 * @file
 * Contains custom functions for astrology.
 */

 /**
  * Function returns day of the year using date function.
  */
function dayofyear2date($day, $format = 'Y-m-d') {
  $date = mktime(0, 0, 0, 1, $day);
  return date($format, $date);
}

/**
 * Function days_array().
 */
function days_array() {
  $days_array = array();
  $i = 1;
  while ($i <= 31) {
    $days_array[$i] = $i;
    $i += 1;
  }
  return $days_array;
}

/**
 * Array of months.
 */
function months_array() {
  $months_array = array(
    1 => 'January',
    2 => 'February',
    3 => 'March',
    4 => 'April',
    5 => 'May',
    6 => 'June',
    7 => 'July',
    8 => 'August',
    9 => 'September',
    10 => 'October',
    11 => 'November',
    12 => t('December'),
  );
  return $months_array;
}

/**
 * Check for default set astrology.
 */
function check_default_astrology($astrology_id, $status, $op = FALSE) {

  $default_astrology = variable_get('astrology_default');

  if ($op && $status == '1') {
    db_update('astrology')
      ->fields(array(
        'enabled' => '0',
      ))->condition('id', $default_astrology, '=')
      ->execute();

    variable_set('astrology_default', $astrology_id);
  }
  elseif ($astrology_id != $default_astrology && $status) {
    db_update('astrology')
      ->fields(array(
        'enabled' => '0',
      ))->condition('id', $default_astrology, '=')
      ->execute();

    variable_set('astrology_default', $astrology_id);
  }
  elseif ($astrology_id == $default_astrology && !$status) {
    db_update('astrology')
      ->fields(array(
        'enabled' => '1',
      ))->condition('id', 1, '=')
      ->execute();
    variable_set('astrology_default', 1);
  }
}

/**
 * Array of years, next 10 years.
 */
function years_array() {
  $years_array = array_combine(range(date("Y"), date("Y") + 1), range(date("Y"), date("Y") + 1));
  return $years_array;
}

/**
 * Get associative array of astrology.
 */
function _get_astrology_array($astrology_id) {
  $astrology = db_select('astrology', 'a')
    ->fields('a')
    ->condition('id', $astrology_id, '=')
    ->execute()
    ->fetchAssoc();
  return $astrology;
}

/**
 * Get astrology List, returns array('id' => int, 'name' => string, ..)
 */
function _get_astrology_list_array() {
  $data = array();
  $rows = db_select('astrology', 'a')
    ->fields('a', array('id', 'name'))
    ->execute();
  while ($row = $rows->fetchObject()) {
    $data[$row->id] = $row->name;
  }
  return $data;
}

/**
 * Get associative array of astrology sign.
 */
function _astrology_sign_array($astrology_sign_id) {
  $astrology = db_select('astrology_signs', 'as_')
    ->fields('as_')
    ->condition('id', $astrology_sign_id, '=')
    ->execute()
    ->fetchAssoc();

  return $astrology;
}

/**
 * Get text for particular astrology sign.
 */
function _get_astrology_sign_text($astrology_sign_id) {
  $astrology = db_select('astrology_text', 'at_')
    ->fields('at_')
    ->condition('id', $astrology_sign_id, '=')
    ->execute()
    ->fetchAssoc();

  return $astrology;
}

/**
 * Astrology sign list, returns array('id' => int, 'name' => string, ..)
 */
function _astrology_sign_list_array($astrology_id) {
  $data = array();
  $data[0] = 'ALL';

  $rows = db_select('astrology_signs', 'as_')
    ->fields('as_', array('id', 'name'))
    ->condition('astrology_id', $astrology_id, '=')
    ->execute();
  while ($row = $rows->fetchObject()) {
    $data[$row->id] = $row->name;
  }

  return $data;
}

/**
 * Generate operations link ex edit delete etc.
 */
function _get_operations_link($row, $context) {

  // Build a list of all the accessible operations for the current Astrology.
  $operations = array();
  $destination = drupal_get_destination();
  switch ($context) {
    case 'astrology-list-one':

      $operations['list_sign'] = array(
        'title' => t('List sign'),
        'href' => "admin/config/astrology/list/$row->id/signs",
      );
      $operations['list_text'] = array(
        'title' => t('List text'),
        'href' => "admin/config/astrology/list/$row->id/list_text",
      );

      break;

    case 'astrology-list-other':
      $operations['list_sign'] = array(
        'title' => t('List sign'),
        'href' => "admin/config/astrology/list/$row->id/signs",
      );
      $operations['add_sign'] = array(
        'title' => t('Add sign'),
        'href' => "admin/config/astrology/list/$row->id/add_sign",
      );
      $operations['list_text'] = array(
        'title' => t('List text'),
        'href' => "admin/config/astrology/list/$row->id/list_text",
      );
      $operations['edit'] = array(
        'title' => t('Edit'),
        'href' => "admin/config/astrology/list/$row->id/edit",
        'query' => $destination,
      );
      $operations['delete'] = array(
        'title' => t('Delete'),
        'href' => "admin/config/astrology/list/$row->id/delete",
        'query' => $destination,
      );
      break;

    case 'astrology-list-sign-one':
      $operations['Add text'] = array(
        'title' => t('Add text'),
        'href' => "admin/config/astrology/list/$row->astrology_id/signs/$row->id/add_text",
      );
      $operations['edit'] = array(
        'title' => t('Edit'),
        'href' => "admin/config/astrology/list/$row->astrology_id/signs/$row->id/edit",
        'query' => $destination,
      );
      break;

    case 'astrology-list-sign-other':
      $operations['Add text'] = array(
        'title' => t('Add text'),
        'href' => "admin/config/astrology/list/$row->astrology_id/signs/$row->id/add_text",
      );
      $operations['edit'] = array(
        'title' => t('Edit'),
        'href' => "admin/config/astrology/list/$row->astrology_id/signs/$row->id/edit",
        'query' => $destination,
      );
      $operations['delete'] = array(
        'title' => t('Delete'),
        'href' => "admin/config/astrology/list/$row->astrology_id/signs/$row->id/delete",
        'query' => $destination,
      );
      break;
  }
  return $operations;
}

/**
 * Display table with all available astrology names.
 */
function _astrology_list() {
  $data = array();
  $header = array(t('Name'), t('Status'), t('Operations'));

  $rows = db_select('astrology', 'a')
    ->fields('a', array('id', 'name', 'enabled'))
    ->execute();

  while ($row = $rows->fetchObject()) {
    if ($row->id == 1) {

      $operations = _get_operations_link($row, 'astrology-list-one');
      $data[] = array(
        'name' => l($row->name, "admin/config/astrology/list/$row->id/signs"),
        'enabled' => ($row->enabled == 1) ? t('<b>Enabled</b> (Default)') : t('Disabled'),
        'operations' => array(
          'data' => array(
            '#theme' => 'links__astrology_operations',
            '#links' => $operations,
            '#attributes' => array('class' => array('links', 'inline')),
          ),
        ),
      );
    }
    else {
      $operations = _get_operations_link($row, 'astrology-list-other');
      $data[] = array(
        'name' => l($row->name, "admin/config/astrology/list/$row->id/signs"),
        'enabled' => ($row->enabled == 1) ? t('<b>Enabled</b> (Default)') : t('Disabled'),
        'operations' => array(
          'data' => array(
            '#theme' => 'links__astrology_operations',
            '#links' => $operations,
            '#attributes' => array('class' => array('links', 'inline')),
          ),
        ),
      );
    }
  }

  $output = theme('table', array(
    'header'  => $header,
    'rows'    => $data,
    'id'      => 'astrology_table',
    'class'   => 'astrology',
  ));

  $astrology_default_form = drupal_get_form('astrology_set_default_form');
  $output .= drupal_render($astrology_default_form);
  return $output;
}

/**
 * Display table of astrological signs.
 */
function _astrology_list_signs($arg) {
  $data = array();
  $header = array(t('Icon'), t('Name'), t('Description'), t('Operations'));
  $query = query_all_signs($arg->id);
  while ($row = $query->fetchObject()) {

    $url = url('astrology/' . drupal_strtolower($row->name));
    $img_url = file_create_url($row->icon);

    $img = t('<a href="@img-link-url">
        <img src="!img-url" alt="!alt" height="20" width="20" /></a>',
         array(
           '@img-link-url' => $url,
           '!img-url' => $img_url,
           '!alt' => $row->name,
         ));
    if ($arg->id == 1) {
      $operations = _get_operations_link($row, 'astrology-list-sign-one');
      $data[] = array(
        'icon' => $img,
        'name' => l(t('!name', array('!name' => $row->name)), 'astrology/' . drupal_strtolower($row->name)),
        'description' => text_summary($row->about_sign, 'fitered_html'),
        'operations' => array(
          'data' => array(
            '#theme' => 'links__astrology_operations',
            '#links' => $operations,
            '#attributes' => array('class' => array('links', 'inline')),
          ),
        ),
      );
    }
    else {
      $operations = _get_operations_link($row, 'astrology-list-sign-other');
      $data[] = array(
        'icon' => $img,
        'name' => l(t('!name', array('!name' => $row->name)), 'astrology/' . drupal_strtolower($row->name)),
        'description' => text_summary($row->about_sign, 'fitered_html'),
        'operations' => array(
          'data' => array(
            '#theme' => 'links__astrology_operations',
            '#links' => $operations,
            '#attributes' => array('class' => array('links', 'inline')),
          ),
        ),
      );
    }
  }
  $message = t('There is no any sign added yet,
   click <a href="@add-sign">Add sign</a> to add sign.', array(
     '@add-sign' => url("admin/config/astrology/list/$arg->id/add_sign"),
   ));
  $caption = t('All available signs from %astrology astrology.', array('%astrology' => $arg->name));

  $table = theme('table', array(
    "header" => $header,
    "rows" => $data,
    "caption" => $caption,
    "empty" => $message,
  ));

  return $table;
}

/**
 * Astrology list sign text.
 */
function _astrology_list_text($astrology_id) {
  $formater = variable_get('astrology_format', 'day');
  $astrology_sign = variable_get('sign_id');
  switch ($formater) {
    case 'day':
      $format = 'z';
      $df = 'Date';
      $newdate = date('m/d/Y');
      $cdate = explode('/', variable_get('cdate', $newdate));
      $timestmp = date('z', mktime(0, 0, 0, $cdate[0], $cdate[1], $cdate[2]));
      if ($astrology_sign) {
        $query = db_select('astrology_text', 'ht');
        $query->join('astrology_signs', 'hs', 'hs.id = ht.astrology_sign_id');
        $query->join('astrology', 'h', 'hs.astrology_id = h.id');
        $query->fields('ht', array(
          'id', 'text', 'value', 'astrology_sign_id', 'post_date',
        ));
        $query->fields('hs', array('icon', 'name', 'astrology_id'));
        $query->fields('h', array('id'));
        $query->condition('h.id', $astrology_id, '=')
          ->condition('hs.id', $astrology_sign, '=')
          ->condition('ht.format_character', $format, '=')
          ->condition('ht.value', $timestmp, '=')
          ->execute();
      }
      else {
        $subquery = db_select('astrology', 'h');
        $subquery->join('astrology_signs', 'hs', 'hs.astrology_id = h.id');
        $subquery->fields('hs', array('id'))
          ->condition('hs.astrology_id', $astrology_id, '=');
        $query = db_select('astrology_text', 'ht');
        $query->join('astrology_signs', 'hs', 'hs.id = ht.astrology_sign_id');
        $query->join('astrology', 'h', 'hs.astrology_id = h.id');
        $query->fields('ht', array(
          'id', 'text', 'value', 'astrology_sign_id', 'post_date',
        ));
        $query->fields('hs', array('icon', 'name'));
        $query->fields('h', array('id'));
        $query->extend('TableSort')->extend('PagerDefault')->limit(5)
          ->condition('h.id', $astrology_id, '=')
          ->condition('astrology_sign_id', $subquery, 'IN')
          ->condition('format_character', $format, '=')
          ->condition('value', $timestmp, '=')
          ->execute();
      }
      break;

    case 'week':
      $format = 'W';
      $df = 'week';
      $newdate = date('m/d/Y');
      $cdate = explode('/', variable_get('cdate', $newdate));
      $timestmp = date('W', mktime(0, 0, 0, $cdate[0], $cdate[1]));
      if ($astrology_sign) {
        $query = db_select('astrology_text', 'ht');
        $query->join('astrology_signs', 'hs', 'hs.id = ht.astrology_sign_id');
        $query->join('astrology', 'h', 'hs.astrology_id = h.id');
        $query->fields('ht', array(
          'id', 'text', 'value', 'astrology_sign_id', 'post_date',
        ));
        $query->fields('hs', array('icon', 'name', 'astrology_id'));
        $query->fields('h', array('id'));
        $query->condition('h.id', $astrology_id, '=')
          ->condition('hs.id', $astrology_sign, '=')
          ->condition('ht.format_character', $format, '=')
          ->condition('ht.value', $timestmp, '=')
          ->execute();
      }
      else {
        $subquery = db_select('astrology', 'h');
        $subquery->join('astrology_signs', 'hs', 'hs.astrology_id = h.id');
        $subquery->fields('hs', array('id'))
          ->condition('hs.astrology_id', $astrology_id, '=');
        $query = db_select('astrology_text', 'ht');
        $query->join('astrology_signs', 'hs', 'hs.id = ht.astrology_sign_id');
        $query->join('astrology', 'h', 'hs.astrology_id = h.id');
        $query->fields('ht', array(
          'id', 'text', 'value', 'astrology_sign_id', 'post_date',
        ));
        $query->fields('hs', array('icon', 'name'));
        $query->fields('h', array('id'));
        $query->extend('TableSort')->extend('PagerDefault')->limit(5)
          ->condition('h.id', $astrology_id, '=')
          ->condition('astrology_sign_id', $subquery, 'IN')
          ->condition('format_character', $format, '=')
          ->condition('value', $timestmp, '=')
          ->execute();
      }
      break;

    case 'month':
      $format = 'n';
      $df = 'month';
      $timestmp = variable_get('cdate', date('n', mktime(0, 0, 0, date("m"), date("d"))));
      if ($astrology_sign) {
        $query = db_select('astrology_text', 'ht');
        $query->join('astrology_signs', 'hs', 'hs.id = ht.astrology_sign_id');
        $query->join('astrology', 'h', 'hs.astrology_id = h.id');
        $query->fields('ht', array(
          'id', 'text', 'value', 'astrology_sign_id', 'post_date',
        ));
        $query->fields('hs', array('icon', 'name', 'astrology_id'));
        $query->fields('h', array('id'));
        $query->condition('h.id', $astrology_id, '=')
          ->condition('hs.id', $astrology_sign, '=')
          ->condition('ht.format_character', $format, '=')
          ->condition('ht.value', $timestmp, '=')
          ->execute();
      }
      else {
        $subquery = db_select('astrology', 'h');
        $subquery->join('astrology_signs', 'hs', 'hs.astrology_id = h.id');
        $subquery->fields('hs', array('id'))
          ->condition('hs.astrology_id', $astrology_id, '=');
        $query = db_select('astrology_text', 'ht');
        $query->join('astrology_signs', 'hs', 'hs.id = ht.astrology_sign_id');
        $query->join('astrology', 'h', 'hs.astrology_id = h.id');
        $query->fields('ht', array(
          'id', 'text', 'value', 'astrology_sign_id', 'post_date',
        ));
        $query->fields('hs', array('icon', 'name'));
        $query->fields('h', array('id'));
        $query->extend('TableSort')->extend('PagerDefault')->limit(5)
          ->condition('h.id', $astrology_id, '=')
          ->condition('astrology_sign_id', $subquery, 'IN')
          ->condition('format_character', $format, '=')
          ->condition('value', $timestmp, '=')
          ->execute();
      }
      $month = date('F, Y', mktime(0, 0, 0, (int) $timestmp, date('d'), date('y')));
      break;

    case 'year':
      $format = 'o';
      $df = 'YEAR';
      $timestmp = variable_get('cdate', date('o', mktime(0, 0, 0, date("m"), date("d"))));
      if ($astrology_sign) {
        $query = db_select('astrology_text', 'ht');
        $query->join('astrology_signs', 'hs', 'hs.id = ht.astrology_sign_id');
        $query->join('astrology', 'h', 'hs.astrology_id = h.id');
        $query->fields('ht', array(
          'id', 'text', 'value', 'astrology_sign_id', 'post_date',
        ));
        $query->fields('hs', array('icon', 'name', 'astrology_id'));
        $query->fields('h', array('id'));
        $query->condition('h.id', $astrology_id, '=')
          ->condition('hs.id', $astrology_sign, '=')
          ->condition('ht.format_character', $format, '=')
          ->condition('ht.value', $timestmp, '=')
          ->execute();
      }
      else {
        $subquery = db_select('astrology', 'h');
        $subquery->join('astrology_signs', 'hs', 'hs.astrology_id = h.id');
        $subquery->fields('hs', array('id'))
          ->condition('hs.astrology_id', $astrology_id, '=');
        $query = db_select('astrology_text', 'ht');
        $query->join('astrology_signs', 'hs', 'hs.id = ht.astrology_sign_id');
        $query->join('astrology', 'h', 'hs.astrology_id = h.id');
        $query->fields('ht', array(
          'id', 'text', 'value', 'astrology_sign_id', 'post_date',
        ));
        $query->fields('hs', array('icon', 'name'));
        $query->fields('h', array('id'));
        $query->extend('TableSort')->extend('PagerDefault')->limit(5)
          ->condition('h.id', $astrology_id, '=')
          ->condition('astrology_sign_id', $subquery, 'IN')
          ->condition('format_character', $format, '=')
          ->condition('value', $timestmp, '=')
          ->execute();
      }
      break;
  }
  $date_format = t('!date-format', array('!date-format' => $df));
  $headers = array(
   array('data' => t('sign')),
   array('data' => t('text')),
   array('data' => $date_format),
   array(
     'data' => t('action'),
   ),
  );

  $result = $query->execute();
  $rows = array();
  $destination = array('query' => array(drupal_get_destination()));

  // Loop through each item and add to the $rows array.
  foreach ($result as $row) {

    $edit = l(t('edit'), 'admin/config/astrology/list_text/' . $row->id . '/edit_text', $destination);
    $img = '<img src="' . file_create_url($row->icon) . '" alt="' . $row->name . '" height="30' . '" width="30' . '"  />';
    $week = date('j, M', mktime(0, 0, 0, date("n", $row->post_date), date("j", $row->post_date) - date("N", $row->post_date))) . ' to ';
    $week .= date('j, M', mktime(0, 0, 0, date("n", $row->post_date), date("j", $row->post_date) - date("N", $row->post_date) + 6));
    $rows[] = array(
      l($img . $row->name, 'astrology/' . drupal_strtolower($row->name), array('html' => TRUE)),
      t(':text', array(':text' => $row->text)),
      (($formater == 'day') ? date('j M,Y', $row->post_date) : (($formater == 'week') ? $week : (($formater == 'month') ? $month : $timestmp))),
      $edit,
    );
  }
  $caption = t('Change default format to view different format from setting page <a href="@change">Change</a>, currently listing !format wise.', array('@change' => url('admin/config/astrology/list'), '!format' => $df));
  $table = theme_table(
    array(
      "header" => $headers,
      "rows" => $rows,
      "attributes" => array(),
      "sticky" => TRUE,
      "caption" => $caption,
      "colgroups" => array(),
      "empty" => t('No data found'),
    )) . theme("pager");
  $astrology_search_text_form = drupal_get_form('astrology_search_text_form', $astrology_id);
  $output = drupal_render($astrology_search_text_form) . $table;
  return $output;
}
